Computation times — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Computation times

00:48.237 total execution time for 5 files from examples06-PyPoscar:

Example | Time | Mem (MB)
--- | --- | ---
Modifying a POSCAR File: Scaling, Supercells, and Defects (`plot_utils_pyposcar.py`) | 00:22.359 | 0.0
Finding defects in a POSCAR file (`plot_finding_defects_pyposcar.py`) | 00:09.143 | 0.0
Substituting Atoms in a POSCAR File (`plot_subsitution_pyposcar.py`) | 00:08.542 | 0.0
Visualizing Clusters in Bi2Se3 Slab (`plot_clusters_pyposcar.py`) | 00:07.662 | 0.0
Analyzing Radial Distribution Functions (RDF) (`plot_rdf_cutoff_pyposcar.py`) | 00:00.531 | 0.0